@@ -17,7 +17,7 @@
 /**
  * Handles Itip response data.
  *
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  * Copyright 2004-2010 Klarälvdalens Datakonsult AB
  *
  * See the enclosed file COPYING for license information (LGPL). If you did not
@@ -124,6 +124,11 @@ class Horde_Itip_Response
         return $vCal;
     }
 
+    protected function _setIcsFilename(Horde_Mime_Part &$message)
+    {
+        $message->setName('event-reply.ics');
+    }
+
     /**
      * Return the response as a MIME message.
      *
@@ -145,14 +150,14 @@ class Horde_Itip_Response
             $this->getIcalendar($type, $options)->exportvCalendar()
         );
         $message->setEOL("\r\n");
-        $message->setName('event-reply.ics');
+        $this->_setIcsFilename($message);
         $message->setContentTypeParameter('METHOD', 'REPLY');
 
         // Build the reply headers.
         $from = $this->_resource->getFrom();
         $reply_to = $this->_resource->getReplyTo();
         $headers = new Horde_Mime_Headers();
-        $headers->addHeader('Date', date('r'));
+        $headers->addHeaderOb(Horde_Mime_Headers_Date::create());
         $headers->addHeader('From', $from);
         $headers->addHeader('To', $this->_request->getOrganizer());
         if (!empty($reply_to) && $reply_to != $from) {
@@ -196,4 +201,4 @@ class Horde_Itip_Response
 
         return array($headers, $message);
     }
-}
\ No newline at end of file
+}
